OiRA - Online διαδραστική Αξιολόγηση Κινδύνων

# Το Υποστατικό

Σε όλους τους χώρους του υποστατικού απαγορεύεται το κάπνισμα. Ναι Όχι

Από τις 14 Ιουνίου του 2002 με βάση το σχετικό νόμο, κάθε εργαζόμενος θα πρέπει να εργάζεται και να αναπαύεται σε χώρους ελεύθερους από καπνό.

Αφήστε τυχόν σχόλια που μπορεί να έχετε σχετικά με την ερώτηση σε αυτό το πεδίο. Αυτά τα σχόλια θα χρησιμοποιηθούνσ το σχέδιο δράσης.

1. Προετοιμασία
2. Αναγνώριση
   1. 1 Το Υποστατικό
      1. Το υποστατικό είναι καλά συντηρημένο
      2. Οι εσωτερικοί χώροι του υποστατικού καθαρίζονται συστηματικά.
      3. Οι παροχές ηλεκτρισμού, υγραερίου και νερού βρίσκονται σε καλή κατάσταση και συντηρούνται καλά.
      4. Στο υποστατικό υπάρχουν υγιειονομικές διευκολύνσεις.
      5. Υπάρχει χώρος ανάπαυσης με ικανοποιητικό αριθμό καθισμάτων.
      6. Σε όλο το υποστατικό τα δάπεδα είναι συγυρισμένα, επίπεδα και αντιολισθητικά.
      7. Καθαρίζονται έγκαιρα οι τρίχες από το δάπεδο και τα έπιπλα.
      8. 1.9 Στους χώρους εργασίας υπάρχει ικανοποιητικός φωτισμός.
      9. test
      10. test
   2. 2 Περιβάλλον εργασίας
   3. 3 Αποφυγή τραυματισμών στο χώρο εργασίας
   4. 4 Δημιουργία καλής ατμόσφαιρας εργασίας και μείωση του άγχους
   5. 5 Χημικοί κίνδυνοι που απειλούν την υγεία
   6. 6 Ατύχημα
   7. 7 Επαγγελματικές Ασθένειες
3. Αξιολόγηση
4. Σχέδιο Δράσης
5. Αναφορά

Δημιουργήθηκε από EU-OSHA. | Σχετικά | Ιδιωτικότητα | Αποποίηση ευθυνών | Άδεια GPL |